==> twipe_flutter_core-1.0.6.tar.gz: test/tester/seeder_tester.dart <==
import 'package:flutter_test/flutter_test.dart';
import 'package:twipe_flutter_core/utils/controller/collection_controller.dart';
import 'package:twipe_flutter_core/utils/controller/controller_manager.dart';
import 'package:twipe_flutter_core/utils/eloquent/model/model.dart';
import 'package:twipe_flutter_core/utils/eloquent/seeder/seeder.dart';
import 'package:twipe_flutter_core/utils/test/tester.dart';

class SeederTester extends Tester {
  static const String collectionId = 'seeder_tester_collection';

  @override
  Future<bool> setup() async {
    return await ControllerManager.registerCollectionController(
        new _TestCollection(collectionId));
  }

  @override
  Future<bool> clear() async {
    return await ControllerManager.getCollectionController(collectionId)
        .clear();
  }

  @override
  Map<String, dynamic> get tests => {'seederCanSeed': seederCanSeed};

  Future<void> seederCanSeed() async {
    await new _Seeder().seed();
    expect(
        ControllerManager.getCollectionController(collectionId)
            .getModels()
            .length,
        13);
  }
}

class _Seeder extends Seeder {
  @override
  String get collectionId => SeederTester.collectionId;

  @override
  Future<void> seed() async {
    await createModel(10, {'label': 'test'});
    await createModel(1, {'label': 'test1'});
    await createModel(2, {'label': 'test2'});
  }
}

///HELPER

class _TestCollection extends CollectionController<_TestModel> {
  _TestCollection(String id) : super(id);

  @override
  _TestModel? createModel(Map<String, dynamic> modelData) {
    _TestModel collectionHelperModel = _TestModel(modelData);
    if (!collectionHelperModel.validate()) {
      return null;
    }
    return collectionHelperModel;
  }
}

class _TestModel extends Model {
  _TestModel(Map<String, dynamic> data) : super(data);

  @override
  List<String> get baseFields => ['id=required'];

  @override
  String get defaultCollection => SeederTester.collectionId;

  @override
  List<String> get hiddenFields => [];

  @override
  List<String> get validator => [];
}

==> twipe_flutter_core-1.0.7.tar.gz: test/tester/seeder_tester.dart <==
import 'package:flutter_test/flutter_test.dart';
import 'package:twipe_flutter_core/utils/controller/collection_controller.dart';
import 'package:twipe_flutter_core/utils/controller/controller_manager.dart';
import 'package:twipe_flutter_core/utils/eloquent/model/model.dart';
import 'package:twipe_flutter_core/utils/eloquent/seeder/seeder.dart';
import 'package:twipe_flutter_core/utils/test/tester.dart';

class SeederTester extends Tester {
  static const String collectionId = 'seeder_tester_collection';

  @override
  Future<bool> setup() async {
    return await ControllerManager.registerCollectionController(
        new _TestCollection(collectionId));
  }

  @override
  Future<bool> clear() async {
    return await ControllerManager.getCollectionController(collectionId)
        .clear();
  }

  @override
  Map<String, dynamic> get tests => {
        'seederCanSeed': seederCanSeed,
      };

  Future<void> seederCanSeed() async {
    await new _Seeder().seed();
    expect(
        ControllerManager.getCollectionController(collectionId)
            .getModels()
            .length,
        13);
  }
}

class _Seeder extends Seeder {
  @override
  String get collectionId => SeederTester.collectionId;

  @override
  Future<void> seed() async {
    await createModel(10, {'label': 'test'});
    await createModel(1, {'label': 'test1'});
    await createModel(2, {'label': 'test2'});
  }
}

///HELPER

class _TestCollection extends CollectionController<_TestModel> {
  _TestCollection(String id) : super(id);

  @override
  _TestModel? createModel(Map<String, dynamic> modelData) {
    _TestModel collectionHelperModel = _TestModel(modelData);
    if (!collectionHelperModel.validate()) {
      return null;
    }
    return collectionHelperModel;
  }
}

class _TestModel extends Model {
  _TestModel(Map<String, dynamic> data) : super(data);

  @override
  List<String> get baseFields => ['id=required'];

  @override
  String get defaultCollection => SeederTester.collectionId;

  @override
  List<String> get hiddenFields => [];

  @override
  List<String> get validator => [];
}
